@@ -1,11 +1,13 @@
 import functools
 import logging
 
-from fastapi import FastAPI
+from fastapi import APIRouter, FastAPI
+from fastapi.middleware.cors import CORSMiddleware
 from fastapi.staticfiles import StaticFiles
 from fastapi.openapi.utils import get_openapi
 from pkg_resources import iter_entry_points
 
+from connect.eaas.core.constants import GUEST_ENDPOINT_ATTR_NAME
 from connect.eaas.core.decorators import router
 from connect.eaas.runner.config import ConfigHelper
 
@@ -13,6 +15,15 @@ from connect.eaas.runner.config import ConfigHelper
 logger = logging.getLogger(__name__)
 
 
+class _OpenApiCORSMiddleware(CORSMiddleware):
+    async def __call__(self, scope, receive, send):
+        if scope['type'] != 'http' or scope['path'] != '/openapi/spec.json':  # pragma: no cover
+            await self.app(scope, receive, send)
+            return
+
+        await super().__call__(scope, receive, send)  # pragma: no cover
+
+
 class WebApp:
     """
     Handle the lifecycle of an extension.
@@ -73,8 +84,14 @@ class WebApp:
         app = FastAPI(
             openapi_url='/openapi/spec.json',
         )
+        app.add_middleware(
+            _OpenApiCORSMiddleware,
+            allow_origins=['https://editor.swagger.io'],
+        )
+        auth, no_auth = self.get_routers()
+        app.include_router(auth, prefix='/api')
+        app.include_router(no_auth, prefix='/guest')
         app.openapi = functools.partial(self.get_api_schema, app)
-        app.include_router(router)
         static_root = self._webapp_class.get_static_root()
         if static_root:
             app.mount('/static', StaticFiles(directory=static_root), name='static')
@@ -110,3 +127,13 @@ class WebApp:
 
         app.openapi_schema = openapi_schema
         return app.openapi_schema
+
+    def get_routers(self):
+        auth = APIRouter()
+        no_auth = APIRouter()
+        for route in router.routes:
+            if getattr(route.endpoint, GUEST_ENDPOINT_ATTR_NAME, False):
+                no_auth.routes.append(route)
+            else:
+                auth.routes.append(route)
+        return auth, no_auth
